Improve this doc

# Error: jqLite:nosel
Unsupported Selector Lookup

    Looking up elements via selectors is not supported by jqLite! See: http://docs.angularjs.org/api/angular.element

## Description

In order to keep Angular small, Angular implements only a subset of the selectors in jqLite. This error occurs when a jqLite instance is invoked with a selector other than this subset.

In order to resolve this error, rewrite your code to only use tag name selectors and manually traverse the DOM using the APIs provided by jqLite.

Alternatively, you can include a full version of jQuery, which Angular will automatically use and that will make all selectors available.